@@ -49,6 +49,8 @@ class GtkObject:
 		_gtk.gtk_signal_connect(self._o, name, f)
 	def connect_after(self, name, f):
 		_gtk.gtk_signal_connect_after(self._o, name, f)
+	def emit_stop_by_name(self, sig):
+		_gtk.gtk_signal_emit_stop_by_name(self._o, sig)
 
 class GtkData(GtkObject):
 	def __init__(self, noinit=None):
@@ -957,7 +959,7 @@ class GtkLabel(GtkMisc):
 	def set_justify(self, jtype):
 		_gtk.gtk_label_set_justify(self._o, jtype)
 	def get(self):
-		return _gtk.gtk_labelget(self._o)
+		return _gtk.gtk_label_get(self._o)
 
 class GtkPreview(GtkWidget):
 	def uninit(self):
